==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaZdk103Ls.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/1
 * @description 宗地空间属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_zdk103_ls")
public class BaZdk103Ls implements Serializable {


    @XmlAttribute
    @id
    @Id
    private String id;
    /**
     * 不动产单元号
     */
    @XmlAttribute
    private String bdcdyh;

    /**
     * 子对象
     */
    @XmlAttribute
    private String zdx;

    /**
     * 序号
     */
    @XmlAttribute
    private String xh;

    /**
     * X坐标
     */
    @XmlAttribute
    private String xzb;

    /**
     * Y坐标
     */
    @XmlAttribute
    private String yzb;

    /**
     * 上图标记字段
     */
    @XmlAttribute
    @Nullable
    private String stbj;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    /**
     * Z坐标
     */
    @XmlAttribute
    private String zzb;

    @XmlAttribute
    private String kjlx;

    private String qxdm;

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getZzb() {
        return zzb;
    }

    public void setZzb(String zzb) {
        this.zzb = zzb;
    }

    public String getKjlx() {
        return kjlx;
    }

    public void setKjlx(String kjlx) {
        this.kjlx = kjlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZdx() {
        return zdx;
    }

    public void setZdx(String zdx) {
        this.zdx = zdx;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getXzb() {
        return xzb;
    }

    public void setXzb(String xzb) {
        this.xzb = xzb;
    }

    public String getYzb() {
        return yzb;
    }

    public void setYzb(String yzb) {
        this.yzb = yzb;
    }

    public String getStbj() {
        return stbj;
    }

    public void setStbj(String stbj) {
        this.stbj = stbj;
    }
}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/entity/BaZdk103Ls.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.jgbsm;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/1
 * @description 宗地空间属性
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_zdk103_ls")
public class BaZdk103Ls implements Serializable {


    @XmlAttribute
    @id
    @Id
    private String id;
    /**
     * 不动产单元号
     */
    @XmlAttribute
    private String bdcdyh;

    /**
     * 子对象
     */
    @XmlAttribute
    private String zdx;

    /**
     * 序号
     */
    @XmlAttribute
    private String xh;

    /**
     * X坐标
     */
    @XmlAttribute
    private String xzb;

    /**
     * Y坐标
     */
    @XmlAttribute
    private String yzb;

    /**
     * 上图标记字段
     */
    @XmlAttribute
    @Nullable
    private String stbj;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    /**
     * Z坐标
     */
    @XmlAttribute
    private String zzb;

    @XmlAttribute
    private String kjlx;

    private String qxdm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 监管标识码 */
    @jgbsm
    private String jgbsf;

    /** 登记状态 */
    @XmlAttribute
    private String djzt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getZzb() {
        return zzb;
    }

    public void setZzb(String zzb) {
        this.zzb = zzb;
    }

    public String getKjlx() {
        return kjlx;
    }

    public void setKjlx(String kjlx) {
        this.kjlx = kjlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZdx() {
        return zdx;
    }

    public void setZdx(String zdx) {
        this.zdx = zdx;
    }

    public String getXh() {
        return xh;
    }

    public void setXh(String xh) {
        this.xh = xh;
    }

    public String getXzb() {
        return xzb;
    }

    public void setXzb(String xzb) {
        this.xzb = xzb;
    }

    public String getYzb() {
        return yzb;
    }

    public void setYzb(String yzb) {
        this.yzb = yzb;
    }

    public String getStbj() {
        return stbj;
    }

    public void setStbj(String stbj) {
        this.stbj = stbj;
    }

    public String getJgbsf() {
        return jgbsf;
    }

    public void setJgbsf(String jgbsf) {
        this.jgbsf = jgbsf;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }
}
